@@ -1,4 +1,4 @@
-/* $Id: bibtexconv.cc 1377 2012-05-13 20:56:15Z dreibh $
+/* $Id: bibtexconv.cc 1487 2012-07-15 11:46:57Z dreibh $
  *
  * BibTeX Converter
  * Copyright (C) 2010-2012 by Thomas Dreibholz
@@ -52,10 +52,129 @@ unsigned long long getMicroTime()
 }
 
 
+// ###### Download file via libcurl #########################################
+static bool downloadFile(CURL*         curl,
+                         const char*   url,
+                         FILE*         headerFH,
+                         FILE*         downloadFH,
+                         unsigned int& errors)
+{
+   if( (ftruncate(fileno(headerFH), 0) != 0) ||
+       (ftruncate(fileno(downloadFH), 0) != 0) ) {
+      perror("Unable to truncate output files");
+      return(false);
+   }
+
+   curl_easy_setopt(curl, CURLOPT_URL,            url);
+   curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 1L);
+   curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 1L);
+   curl_easy_setopt(curl, CURLOPT_WRITEDATA,      downloadFH);
+   curl_easy_setopt(curl, CURLOPT_WRITEHEADER,    headerFH);
+   curl_easy_setopt(curl, CURLOPT_USERAGENT,      "bibtexconv/1.0 (compatible; MC680x0; AmigaOS)");
+   curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);   // follow redirects
+   curl_easy_setopt(curl, CURLOPT_AUTOREFERER,    1L);   // set referer on redirect
+   curl_easy_setopt(curl, CURLOPT_COOKIEFILE,     "");   // enable cookies
+   curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 30);   // 30s connect timeout
+
+   bool  resultIsGood    = false;
+   const CURLcode result = curl_easy_perform(curl);
+   if(result == CURLE_OK) {
+      rewind(headerFH);
+      rewind(downloadFH);
+
+      // ====== Check HTTP result =========================
+      if( (strncmp(url, "http", 4)) == 0) {
+         unsigned int v1, v2, httpErrorCode = 999;
+         char         header[8192];
+         while(!feof(headerFH)) {
+            // The actual result will be of the last request
+            // in the header file (may have been redirected!)
+            if(!fgets((char*)&header, sizeof(header) - 1, headerFH)) {
+               break;
+            }
+            sscanf(header, "HTTP/%u.%u %u ", &v1, &v2, &httpErrorCode);
+         }
+         if(httpErrorCode == 200) {
+             resultIsGood = true;
+         }
+         if(httpErrorCode != 200) {
+            fprintf(stderr, "FAILED %s - HTTP returns code %u!\n",
+                    url, httpErrorCode);
+
+            /*
+            rewind(headerFH);
+            size_t r = fread((char*)&header, 1, sizeof(header) - 1, headerFH);
+            if(r > 0) {
+               header[r] = 0x00;
+               fputs(header, stderr);
+            }
+            */
+
+            errors++;
+         }
+      }
+   }
+   else {
+      fprintf(stderr, "FAILED %s: %s!\n", url, curl_easy_strerror(result));
+      errors++;
+   }
+
+   return(resultIsGood);
+}
+
+
+// ###### Dynamic URL handling ##############################################
+static bool handleDynamicURL(CURL*             curl,
+                             const std::string url,
+                             FILE*             headerFH,
+                             FILE*             downloadFH,
+                             unsigned int&     errors)
+{
+   std::string rest;
+   std::string newURL = "";
+
+   // ====== IEEExplore database ============================================
+   if( (hasPrefix(url, "http://ieeexplore.ieee.org/", rest)) ||
+       (hasPrefix(url, "https://ieeexplore.ieee.org/", rest)) ) {
+      char buffer[65536];
+      size_t r = fread((char*)&buffer, 1, sizeof(buffer) - 1, downloadFH);
+      if((r > 0) && (r < sizeof(buffer) - 1)) {
+         buffer[r] = 0x00;
+
+         fprintf(stderr, "[IEEExplore");
+
+         const std::string inputString(buffer);
+         const size_t      framePos = inputString.rfind("<frame src=\"");
+         // fputs(inputString.c_str(),stderr);
+         if(framePos != std::string::npos) {
+            const size_t a = inputString.find("\"", framePos);
+            const size_t b = inputString.find("\"", a + 1);
+            if( (a != std::string::npos) && (b != std::string::npos) ) {
+               newURL = inputString.substr(a + 1, b - a - 1);
+               fprintf(stderr, "->%s", newURL.c_str());
+            }
+         }
+
+         fprintf(stderr, "] ");
+      }
+   }
+
+   rewind(headerFH);
+   rewind(downloadFH);
+   if(newURL.size() > 0) {
+      // printf("NEW=<%s>\n", newURL.c_str());
+      return(downloadFile(curl, newURL.c_str(), headerFH, downloadFH, errors));
+   }
+
+   return(true);
+}
+
+
 // ###### Check URLs ########################################################
 unsigned int checkAllURLs(PublicationSet* publicationSet,
                           const char*     downloadDirectory,
-                          const bool      checkNewURLsOnly)
+                          const bool      checkNewURLsOnly,
+                          const bool      ignoreUpdatesForHTML)
 {
    if(downloadDirectory != NULL) {
       if( (mkdir(downloadDirectory, S_IRWXU|S_IXGRP|S_IRGRP|S_IXOTH|S_IROTH) < 0) &&
@@ -66,6 +185,12 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
       }
    }
 
+   CURL* curl = curl_easy_init();
+   if(curl == NULL) {
+      fputs("ERROR: Failed to initialize libcurl!\n", stderr);
+      exit(1);
+   }
+
    unsigned int errors = 0;
    for(size_t index = 0; index < publicationSet->size(); index++) {
       // ====== Get prev, current and next publications =====================
@@ -109,7 +234,7 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
          else {
             snprintf((char*)&downloadFileName, sizeof(downloadFileName), "%s", "/tmp/bibtexconv-dXXXXXX");
          }
-         snprintf((char*)&mimeFileName, sizeof(mimeFileName), "%s",     "/tmp/bibtexconv-mXXXXXX");
+         snprintf((char*)&mimeFileName, sizeof(mimeFileName), "%s",      "/tmp/bibtexconv-mXXXXXX");
 
          if( (mkstemp((char*)&downloadFileName) > 0) &&
              (mkstemp((char*)&mimeFileName) > 0) ) {
@@ -117,165 +242,150 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
             if(downloadFH != NULL) {
                FILE* headerFH = tmpfile();
                if(headerFH != NULL) {
-                  CURL* curl = curl_easy_init();
-                  if(curl != NULL) {
-                     curl_easy_setopt(curl, CURLOPT_URL,            url->value.c_str());
-                     curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
-                     curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0L);
-                     curl_easy_setopt(curl, CURLOPT_WRITEDATA,      downloadFH);
-                     curl_easy_setopt(curl, CURLOPT_WRITEHEADER,    headerFH);
-                     curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1L);   // follow redirects
-                     curl_easy_setopt(curl, CURLOPT_AUTOREFERER,    1L);   // set referer on redirect
+                  bool resultIsGood = downloadFile(curl, url->value.c_str(), headerFH, downloadFH, errors);
+                  if(resultIsGood) {
+                     // Special handling for dynamic URLs of some publishers
+                     resultIsGood = handleDynamicURL(curl, url->value, headerFH, downloadFH, errors);
+                  }
+                  if(resultIsGood) {
+                     unsigned long long totalSize = 0;
+                     unsigned char      md5[MD5_DIGEST_LENGTH];
+                     MD5_CTX md5_ctx;
+                     MD5_Init(&md5_ctx);
 
-                     const CURLcode result = curl_easy_perform(curl);
-                     if(result == CURLE_OK) {
-                        unsigned long long totalSize = 0;
-                        rewind(headerFH);
-                        rewind(downloadFH);
+                     // ====== Compute size and MD5 =========================
+                     while(!feof(downloadFH)) {
+                        char input[16384];
+                        const size_t bytesRead = fread(&input, 1, sizeof(input), downloadFH);
+                        if(bytesRead > 0) {
+                           totalSize += (unsigned long long)bytesRead;
+                           MD5_Update(&md5_ctx, &input, bytesRead);
+                        }
+                     }
 
-                        // ====== Check HTTP result =========================
-                        bool resultIsGood = true;
-                        if( (strncmp(url->value.c_str(), "http", 4)) == 0) {
-                           unsigned int v1, v2, httpErrorCode = 999;
-                           char         header[8192];
-                           while(!feof(headerFH)) {
-                              // The actual result will be of the last request
-                              // in the header file (may have been redirected!)
-                              if(!fgets((char*)&header, sizeof(header) - 1, headerFH)) {
-                                 break;
+                     if(totalSize > 0) {
+                        // ====== Compute mime type (using "file") =======
+                        std::string mimeString;
+                        std::string command = format("/usr/bin/file --mime-type -b %s >%s", downloadFileName, mimeFileName);
+                        if(system(command.c_str()) == 0) {
+                           FILE* mimeFH = fopen(mimeFileName, "r");
+                           if(mimeFH != NULL) {
+                              char input[1024];
+                              if(fgets((char*)&input, sizeof(input) - 1, mimeFH) != NULL) {
+                                 mimeString = std::string(input);
+                                 if( (mimeString.size() > 0) &&
+                                     (mimeString[mimeString.size() - 1] == '\n') ) {
+                                    mimeString = mimeString.substr(0, mimeString.size() - 1);
+                                 }
                               }
-                              sscanf(header, "HTTP/%u.%u %u ", &v1, &v2, &httpErrorCode);
-                           }
-                           if(httpErrorCode != 200) {
-                              resultIsGood = false;
-                              fprintf(stderr, "FAILED %s - HTTP returns code %u!\n",
-                                      url->value.c_str(), httpErrorCode);
-/*
-                              rewind(headerFH);
-                              size_t r = fread((char*)&header, 1, sizeof(header) - 1, headerFH);
-                              if(r > 0) {
-                                 header[r] = 0x00;
-                                 fputs(header, stderr);
-                              }
-*/
-                              errors++;
+                              fclose(mimeFH);
                            }
                         }
+                        else {
+                           fprintf(stderr, "FAILED %s: failed to obtain mime type of download file!\n",
+                                   url->value.c_str());
+                        }
 
-                        if(resultIsGood) {
-                           unsigned char md5[MD5_DIGEST_LENGTH];
-                           MD5_CTX md5_ctx;
-                           MD5_Init(&md5_ctx);
+                        // ====== Compare size, mime type and MD5 ===========
+                        std::string sizeString = format("%llu", totalSize);
+                        std::string md5String;
+                        MD5_Final((unsigned char*)&md5, &md5_ctx);
+                        for(unsigned int i = 0; i < MD5_DIGEST_LENGTH; i++) {
+                           md5String += format("%02x", (unsigned int)md5[i]);
+                        }
+                        const Node* urlMimeNode = findChildNode(publication, "url.mime");
+                        const Node* urlSizeNode = findChildNode(publication, "url.size");
+                        const Node* urlMD5Node  = findChildNode(publication, "url.md5");
 
-                           // ====== Compute size and MD5 ======================
-                           while(!feof(downloadFH)) {
-                              char input[16384];
-                              const size_t bytesRead = fread(&input, 1, sizeof(input), downloadFH);
-                              if(bytesRead > 0) {
-                                 totalSize += (unsigned long long)bytesRead;
-                                 MD5_Update(&md5_ctx, &input, bytesRead);
-                              }
-                           }
-
-                           if(totalSize > 0) {
-                              // ====== Compute mime type (using "file") =======
-                              std::string mimeString;
-                              std::string command = format("/usr/bin/file --mime-type -b %s >%s", downloadFileName, mimeFileName);
-                              if(system(command.c_str()) == 0) {
-                                 FILE* mimeFH = fopen(mimeFileName, "r");
-                                 if(mimeFH != NULL) {
-                                    char input[1024];
-                                    if(fgets((char*)&input, sizeof(input) - 1, mimeFH) != NULL) {
-                                       mimeString = std::string(input);
-                                       if( (mimeString.size() > 0) &&
-                                           (mimeString[mimeString.size() - 1] == '\n') ) {
-                                          mimeString = mimeString.substr(0, mimeString.size() - 1);
-                                       }
-                                    }
-                                    fclose(mimeFH);
-                                 }
-                              }
-                              else {
-                                 fprintf(stderr, "FAILED %s: failed to obtain mime type of download file!\n",
-                                         url->value.c_str());
-                              }
-
-                              // ====== Compare size, mime type and MD5 ========
-                              std::string sizeString = format("%llu", totalSize);
-                              std::string md5String;
-                              MD5_Final((unsigned char*)&md5, &md5_ctx);
-                              for(unsigned int i = 0; i < MD5_DIGEST_LENGTH; i++) {
-                                 md5String += format("%02x", (unsigned int)md5[i]);
-                              }
-
-                              const Node* urlSizeNode = findChildNode(publication, "url.size");
-                              if((urlSizeNode != NULL) && (urlSizeNode->value != sizeString)) {
-                                 fprintf(stderr, "FAILED %s: old size has been %s, new size is %s\n",
-                                         url->value.c_str(),
-                                         urlSizeNode->value.c_str(), sizeString.c_str());
-                                 errors++;
-                              }
-                              const Node* urlMimeNode = findChildNode(publication, "url.mime");
-                              if((urlMimeNode != NULL) && (urlMimeNode->value != mimeString)) {
-                                 fprintf(stderr, "FAILED %s: old mime type has been %s, new type mime is %s\n",
-                                         url->value.c_str(),
-                                         urlMimeNode->value.c_str(), mimeString.c_str());
-                                 errors++;
-                              }
-                              const Node* urlMD5Node = findChildNode(publication, "url.md5");
-                              if((urlMD5Node != NULL) && (urlMD5Node->value != md5String)) {
-                                 fprintf(stderr, "FAILED %s: old MD5 has been %s, new MD5 is %s\n",
-                                         url->value.c_str(),
-                                         urlMD5Node->value.c_str(), md5String.c_str());
-                                 errors++;
-                              }
-
-                              // ====== Update size, mime type and MD5 =========
-                              addOrUpdateChildNode(publication, "url.size", sizeString.c_str());
-                              addOrUpdateChildNode(publication, "url.mime", mimeString.c_str());
-                              addOrUpdateChildNode(publication, "url.md5",  md5String.c_str());
-
-                              // ====== Update check time ======================
-                              const unsigned long long microTime = getMicroTime();
-                              const time_t             timeStamp = microTime / 1000000;
-                              const tm*                timeptr   = localtime(&timeStamp);
-                              char  checkTime[128];
-                              strftime((char*)&checkTime, sizeof(checkTime), "%Y-%m-%d %H:%M:%S %Z", timeptr);
-                              addOrUpdateChildNode(publication, "url.checked", checkTime);
-
-                              fprintf(stderr, "OK: size=%sB; type=%s; MD5=%s\n",
-                                      sizeString.c_str(), mimeString.c_str(), md5String.c_str());
-
-                              if(downloadDirectory != NULL) {
-                                 fclose(downloadFH);
-                                 downloadFH = NULL;
-                                 const std::string newFileName =
-                                    PublicationSet::makeDownloadFileName(downloadDirectory, publication->keyword, mimeString);
-                                 if(rename(downloadFileName, newFileName.c_str()) < 0) {
-                                    unlink(downloadFileName);
-                                    fprintf(stderr, "FAILED to store download file %s: %s!\n",
-                                            newFileName.c_str(), strerror(errno));
-                                    exit(1);
-                                 }
-                              }
+                        bool failed = false;
+                        if((urlMimeNode != NULL) && (urlMimeNode->value != mimeString)) {
+                           if( (urlMimeNode->value == "text/html") &&
+                               (mimeString == "application/pdf") ) {
+                              fprintf(stderr, "\nNOTE: change from HTML to PDF -> just updating entry\n");
+                              urlSizeNode = NULL;
+                              urlMD5Node  = NULL;
                            }
                            else {
-                              fprintf(stderr, "FAILED %s: size is zero!\n", url->value.c_str());
-                              errors++;
+                              fprintf(stderr, "FAILED %s: old mime type has been %s, new type mime is %s\n",
+                                      url->value.c_str(),
+                                      urlMimeNode->value.c_str(), mimeString.c_str());
+                              errors++; failed = true;
+                           }
+                        }
+                        if( (!failed) && (urlSizeNode != NULL) && (urlSizeNode->value != sizeString) ) {
+                            if( (ignoreUpdatesForHTML == true) &&
+                                ((urlMimeNode != NULL) &&
+                                 ((urlMimeNode->value == "text/html") ||
+                                  (urlMimeNode->value == "application/xml"))) ) {
+                               md5String = "ignore";
+                               fprintf(stderr, "[Size change for HTML/XML document -> setting url.md5=\"ignore\"] ");
+                            }
+                            else {
+                              fprintf(stderr, "FAILED %s: old size has been %s, new size is %s\n",
+                                      url->value.c_str(),
+                                      urlSizeNode->value.c_str(), sizeString.c_str());
+                              errors++; failed = true;
+                            }
+                        }
+                        if( (!failed) && (urlMD5Node != NULL) && (urlMD5Node->value != "ignore") &&
+                           (urlMD5Node->value != md5String)) {
+                            if( (ignoreUpdatesForHTML == true) &&
+                                ((urlMimeNode != NULL) &&
+                                 ((urlMimeNode->value == "text/html") ||
+                                  (urlMimeNode->value == "application/xml"))) ) {
+                               md5String = "ignore";
+                               fprintf(stderr, "[MD5 change for HTML/XML document -> setting url.md5=\"ignore\"] ");
+                            }
+                            else {
+                               fprintf(stderr, "FAILED %s: old MD5 has been %s, new MD5 is %s\n",
+                                       url->value.c_str(),
+                                       urlMD5Node->value.c_str(), md5String.c_str());
+                               errors++; failed = true;
+                            }
+                        }
+
+                        // ====== Update metadata ===========================
+                        if(!failed) {
+                           // ====== Update size, mime type and MD5 =========
+                           addOrUpdateChildNode(publication, "url.size", sizeString.c_str());
+                           addOrUpdateChildNode(publication, "url.mime", mimeString.c_str());
+                           if( (urlMD5Node == NULL) || (urlMD5Node->value != "ignore")) {
+                              addOrUpdateChildNode(publication, "url.md5",  md5String.c_str());
+                           }
+
+                           // ====== Update check time ======================
+                           const unsigned long long microTime = getMicroTime();
+                           const time_t             timeStamp = microTime / 1000000;
+                           const tm*                timeptr   = localtime(&timeStamp);
+                           char  checkTime[128];
+                           strftime((char*)&checkTime, sizeof(checkTime), "%Y-%m-%d %H:%M:%S %Z", timeptr);
+                           addOrUpdateChildNode(publication, "url.checked", checkTime);
+
+                           fprintf(stderr, "OK: size=%sB; type=%s; MD5=%s\n",
+                                   sizeString.c_str(), mimeString.c_str(), md5String.c_str());
+
+                           // ====== Move downloaded file ===================
+                           if(downloadDirectory != NULL) {
+                              fclose(downloadFH);
+                              downloadFH = NULL;
+                              const std::string newFileName =
+                                 PublicationSet::makeDownloadFileName(downloadDirectory, publication->keyword, mimeString);
+                              if(rename(downloadFileName, newFileName.c_str()) < 0) {
+                                 unlink(downloadFileName);
+                                 fprintf(stderr, "\nFAILED to store download file %s: %s!\n",
+                                         newFileName.c_str(), strerror(errno));
+                                 exit(1);
+                              }
                            }
                         }
                      }
                      else {
-                        fprintf(stderr, "FAILED %s: %s!\n", url->value.c_str(), curl_easy_strerror(result));
+                        fprintf(stderr, "\nFAILED %s: size is zero!\n", url->value.c_str());
                         errors++;
                      }
-                     curl_easy_cleanup(curl);
-                  }
-                  else {
-                     fputs("ERROR: Failed to initialize libcurl!\n", stderr);
-                     exit(1);
                   }
                   fclose(headerFH);
+                  headerFH = NULL;
                }
                else {
                   fputs("ERROR: Failed to create temporary header file!\n", stderr);
@@ -283,6 +393,7 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
                }
                if(downloadFH != NULL) {
                   fclose(downloadFH);
+                  downloadFH = NULL;
                   unlink(downloadFileName);
                }
                unlink(mimeFileName);
@@ -298,6 +409,10 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
          }
       }
    }
+
+   curl_easy_cleanup(curl);
+   curl = NULL;
+
    return(errors);
 }
 
@@ -316,6 +431,7 @@ static int handleInput(FILE*           fh,
                        const char*     downloadDirectory,
                        const bool      checkURLs,
                        const bool      checkNewURLsOnly,
+                       const bool      ignoreUpdatesForHTML,
                        const char*     exportToBibTeX,
                        const char*     exportToSeparateBibTeXs,
                        const char*     exportToXML,
@@ -413,7 +529,7 @@ static int handleInput(FILE*           fh,
          }
          else if((strncmp(input, "export", 5)) == 0) {
             if(checkURLs) {
-               result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly);
+               result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly, ignoreUpdatesForHTML);
             }
             const char* namingTemplate = "%u";
             if(input[6] == ' ') {
@@ -495,7 +611,7 @@ static int handleInput(FILE*           fh,
                FILE* includeFH = fopen(includeFileName, "r");
                if(includeFH != NULL) {
                   result += handleInput(includeFH, publicationSet,
-                                        downloadDirectory, checkURLs, checkNewURLsOnly,
+                                        downloadDirectory, checkURLs, checkNewURLsOnly, ignoreUpdatesForHTML,
                                         exportToBibTeX, exportToSeparateBibTeXs,
                                         exportToXML, exportToSeparateXMLs,
                                         skipNotesWithISBNandISSN, addNotesWithISBNandISSN,
@@ -547,6 +663,7 @@ int main(int argc, char** argv)
    bool        interactive              = true;
    bool        checkURLs                = false;
    bool        checkNewURLsOnly         = false;
+   bool        ignoreUpdatesForHTML     = false;
    bool        skipNotesWithISBNandISSN = false;
    bool        addNotesWithISBNandISSN  = false;
    bool        addUrlCommand            = false;
@@ -571,7 +688,7 @@ int main(int argc, char** argv)
    monthNames.push_back("December");
 
    if(argc < 2) {
-      fprintf(stderr, "Usage: %s BibTeX_File {-export-to-bibtex=file} {-export-to-separate-bibtexs=prefix} {-export-to-xml=file} {-export-to-separate-xmls=prefix} {-export-to-custom=file} {-non-interactive} {-nbsp=string} {-check-urls} {-only-check-new-urls} {-add-url-command} {-skip-notes-with-isbn-and-issn} {-add-notes-with-isbn-and-issn} {-store-downloads=directory}\n", argv[0]);
+      fprintf(stderr, "Usage: %s BibTeX_File {-export-to-bibtex=file} {-export-to-separate-bibtexs=prefix} {-export-to-xml=file} {-export-to-separate-xmls=prefix} {-export-to-custom=file} {-non-interactive} {-nbsp=string} {-check-urls} {-only-check-new-urls} {-ignore-updates-for-html} {-add-url-command} {-skip-notes-with-isbn-and-issn} {-add-notes-with-isbn-and-issn} {-store-downloads=directory}\n", argv[0]);
       exit(1);
    }
    for(int i = 2; i < argc; i++) {
@@ -605,6 +722,9 @@ int main(int argc, char** argv)
       else if( strcmp(argv[i], "-only-check-new-urls") == 0 ) {
          checkNewURLsOnly = true;
       }
+      else if( strcmp(argv[i], "-ignore-updates-for-html") == 0 ) {
+         ignoreUpdatesForHTML = true;
+      }
       else if( strcmp(argv[i], "-add-url-command") == 0 ) {
          addUrlCommand = true;
       }
@@ -634,7 +754,7 @@ int main(int argc, char** argv)
       if(!interactive) {
          publicationSet.addAll(bibTeXFile);
          if(checkURLs) {
-            result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly);
+            result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly, ignoreUpdatesForHTML);
          }
 
          // ====== Export all to BibTeX =====================================
@@ -683,7 +803,7 @@ int main(int argc, char** argv)
          fprintf(stderr, "Got %u publications from BibTeX file.\n",
                  (unsigned int)publicationSet.maxSize());
          result = handleInput(stdin, publicationSet,
-                              downloadDirectory, checkURLs, checkNewURLsOnly,
+                              downloadDirectory, checkURLs, checkNewURLsOnly, ignoreUpdatesForHTML,
                               exportToBibTeX, exportToSeparateBibTeXs,
                               exportToXML, exportToSeparateXMLs,
                               skipNotesWithISBNandISSN, addNotesWithISBNandISSN,
