@@ -149,7 +149,7 @@ typedef union YYSTYPE
 {
 
 /* Line 293 of yacc.c  */
-#line 58 "grammar.yy"
+#line 62 "grammar.yy"
 
    char*        iText;
    struct Node* nodePtr;
@@ -470,9 +470,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    66,    66,    70,    71,    75,    77,    79,    81,    83,
-      85,    87,    89,    91,    93,    98,    99,   100,   101,   105,
-     106,   107,   108,   113,   114,   119
+       0,    70,    70,    74,    75,    79,    81,    83,    85,    87,
+      89,    91,    93,    95,    97,   102,   103,   104,   105,   109,
+     110,   111,   112,   117,   118,   123
 };
 #endif
 
@@ -1143,6 +1143,33 @@ yydestruct (yymsg, yytype, yyvaluep)
 
   switch (yytype)
     {
+      case 17: /* "T_Keyword" */
+
+/* Line 1391 of yacc.c  */
+#line 50 "grammar.yy"
+	{ free((yyvaluep->iText)); };
+
+/* Line 1391 of yacc.c  */
+#line 1154 "grammar.cc"
+	break;
+      case 18: /* "T_String" */
+
+/* Line 1391 of yacc.c  */
+#line 51 "grammar.yy"
+	{ free((yyvaluep->iText)); };
+
+/* Line 1391 of yacc.c  */
+#line 1163 "grammar.cc"
+	break;
+      case 19: /* "T_Comment" */
+
+/* Line 1391 of yacc.c  */
+#line 52 "grammar.yy"
+	{ free((yyvaluep->iText)); };
+
+/* Line 1391 of yacc.c  */
+#line 1172 "grammar.cc"
+	break;
 
       default:
 	break;
@@ -1444,175 +1471,175 @@ yyreduce:
         case 2:
 
 /* Line 1806 of yacc.c  */
-#line 66 "grammar.yy"
+#line 70 "grammar.yy"
     { bibTeXFile = (yyval.nodePtr); }
     break;
 
   case 3:
 
 /* Line 1806 of yacc.c  */
-#line 70 "grammar.yy"
+#line 74 "grammar.yy"
     { (yyval.nodePtr) = makePublicationCollection((yyvsp[(1) - (2)].nodePtr), (yyvsp[(2) - (2)].nodePtr));   }
     break;
 
   case 4:
 
 /* Line 1806 of yacc.c  */
-#line 71 "grammar.yy"
+#line 75 "grammar.yy"
     { (yyval.nodePtr) = (yyvsp[(1) - (1)].nodePtr); }
     break;
 
   case 5:
 
 /* Line 1806 of yacc.c  */
-#line 76 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("Comment", (yyvsp[(1) - (1)].iText), NULL); }
+#line 80 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("Comment", (yyvsp[(1) - (1)].iText), NULL); free((yyvsp[(1) - (1)].iText)); }
     break;
 
   case 6:
 
 /* Line 1806 of yacc.c  */
-#line 78 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("Article", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 82 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("Article", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 7:
 
 /* Line 1806 of yacc.c  */
-#line 80 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("Book", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 84 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("Book", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 8:
 
 /* Line 1806 of yacc.c  */
-#line 82 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("InCollection", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 86 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("InCollection", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 9:
 
 /* Line 1806 of yacc.c  */
-#line 84 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("InProceedings", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 88 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("InProceedings", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 10:
 
 /* Line 1806 of yacc.c  */
-#line 86 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("Manual", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 90 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("Manual", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 11:
 
 /* Line 1806 of yacc.c  */
-#line 88 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("MastersThesis", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 92 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("MastersThesis", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 12:
 
 /* Line 1806 of yacc.c  */
-#line 90 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("Misc", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 94 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("Misc", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 13:
 
 /* Line 1806 of yacc.c  */
-#line 92 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("PhDThesis", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 96 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("PhDThesis", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 14:
 
 /* Line 1806 of yacc.c  */
-#line 94 "grammar.yy"
-    { (yyval.nodePtr) = makePublication("TechReport", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); }
+#line 98 "grammar.yy"
+    { (yyval.nodePtr) = makePublication("TechReport", (yyvsp[(4) - (7)].iText), (yyvsp[(6) - (7)].nodePtr)); free((yyvsp[(4) - (7)].iText)); }
     break;
 
   case 15:
 
 /* Line 1806 of yacc.c  */
-#line 98 "grammar.yy"
+#line 102 "grammar.yy"
     { (yyval.nodePtr) = makePublicationInfo((yyvsp[(1) - (3)].nodePtr), (yyvsp[(3) - (3)].nodePtr)); }
     break;
 
   case 16:
 
 /* Line 1806 of yacc.c  */
-#line 99 "grammar.yy"
-    { (yyval.nodePtr) = makePublicationInfo((yyvsp[(1) - (4)].nodePtr), (yyvsp[(4) - (4)].nodePtr)); }
+#line 103 "grammar.yy"
+    { (yyval.nodePtr) = makePublicationInfo((yyvsp[(1) - (4)].nodePtr), (yyvsp[(4) - (4)].nodePtr)); free((yyvsp[(3) - (4)].iText)); }
     break;
 
   case 17:
 
 /* Line 1806 of yacc.c  */
-#line 100 "grammar.yy"
-    { (yyval.nodePtr) = (yyvsp[(1) - (3)].nodePtr); }
+#line 104 "grammar.yy"
+    { (yyval.nodePtr) = (yyvsp[(1) - (3)].nodePtr); free((yyvsp[(2) - (3)].iText)); }
     break;
 
   case 18:
 
 /* Line 1806 of yacc.c  */
-#line 101 "grammar.yy"
+#line 105 "grammar.yy"
     { (yyval.nodePtr) = (yyvsp[(1) - (1)].nodePtr); }
     break;
 
   case 19:
 
 /* Line 1806 of yacc.c  */
-#line 105 "grammar.yy"
-    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (3)].iText), (yyvsp[(3) - (3)].iText)); }
+#line 109 "grammar.yy"
+    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (3)].iText), (yyvsp[(3) - (3)].iText)); free((yyvsp[(1) - (3)].iText)); free((yyvsp[(3) - (3)].iText)); }
     break;
 
   case 20:
 
 /* Line 1806 of yacc.c  */
-#line 106 "grammar.yy"
-    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (3)].iText), (yyvsp[(3) - (3)].iText)); }
+#line 110 "grammar.yy"
+    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (3)].iText), (yyvsp[(3) - (3)].iText)); free((yyvsp[(1) - (3)].iText)); free((yyvsp[(3) - (3)].iText)); }
     break;
 
   case 21:
 
 /* Line 1806 of yacc.c  */
-#line 107 "grammar.yy"
-    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (5)].iText), (yyvsp[(4) - (5)].iText)); }
+#line 111 "grammar.yy"
+    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (5)].iText), (yyvsp[(4) - (5)].iText)); free((yyvsp[(1) - (5)].iText)); free((yyvsp[(4) - (5)].iText)); }
     break;
 
   case 22:
 
 /* Line 1806 of yacc.c  */
-#line 108 "grammar.yy"
-    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (5)].iText), (yyvsp[(4) - (5)].iText)); }
+#line 112 "grammar.yy"
+    { (yyval.nodePtr) = makePublicationInfoItem((yyvsp[(1) - (5)].iText), (yyvsp[(4) - (5)].iText)); free((yyvsp[(1) - (5)].iText)); free((yyvsp[(4) - (5)].iText)); }
     break;
 
   case 23:
 
 /* Line 1806 of yacc.c  */
-#line 113 "grammar.yy"
-    { (yyval.nodePtr) = NULL; }
+#line 117 "grammar.yy"
+    { free((yyvsp[(2) - (3)].iText)); (yyval.nodePtr) = NULL; }
     break;
 
   case 24:
 
 /* Line 1806 of yacc.c  */
-#line 114 "grammar.yy"
-    { (yyval.nodePtr) = NULL; }
+#line 118 "grammar.yy"
+    { free((yyvsp[(1) - (1)].iText)); (yyval.nodePtr) = NULL; }
     break;
 
   case 25:
 
 /* Line 1806 of yacc.c  */
-#line 119 "grammar.yy"
-    { (yyval.nodePtr) = NULL; }
+#line 123 "grammar.yy"
+    { free((yyvsp[(1) - (1)].iText)); (yyval.nodePtr) = NULL; }
     break;
 
 
 
 /* Line 1806 of yacc.c  */
-#line 1616 "grammar.cc"
+#line 1643 "grammar.cc"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
