@@ -1,4 +1,4 @@
-/* $Id: node.cc 1342 2012-02-10 18:34:09Z dreibh $
+/* $Id: node.cc 1478 2012-07-14 14:47:17Z dreibh $
  *
  * BibTeX Converter
  * Copyright (C) 2010-2012 by Thomas Dreibholz
@@ -459,6 +459,9 @@ Node* makePublicationInfoItem(const char* keyword, const char* value)
       node->priority = 230;
    }
 
+   else if(node->keyword == "language") {
+      node->priority = 225;
+   }
    else if(node->keyword == "isbn") {
       node->priority = 224;
    }
@@ -481,10 +484,10 @@ Node* makePublicationInfoItem(const char* keyword, const char* value)
    else if(node->keyword == "url.size") {
       node->priority = 198;
    }
-   else if(node->keyword == "url.mime") {
+   else if(node->keyword == "url.md5") {
       node->priority = 197;
    }
-   else if(node->keyword == "url.md5") {
+   else if(node->keyword == "url.mime") {
       node->priority = 196;
    }
    else if(node->keyword == "url.checked") {
