@@ -1,4 +1,4 @@
-/* $Id: stringhandling.cc 1342 2012-02-10 18:34:09Z dreibh $
+/* $Id: stringhandling.cc 1467 2012-07-13 21:34:09Z dreibh $
  *
  * BibTeX Converter
  * Copyright (C) 2010-2012 by Thomas Dreibholz
@@ -294,3 +294,14 @@ std::string format(const char* fmt, ...)
    va_end(va);
    return(std::string(buffer));
 }
+
+
+// ###### Check string for given prefix #####################################
+bool hasPrefix(const std::string& string, const std::string& prefix, std::string& rest)
+{
+   if(string.substr(0, prefix.size()) == prefix) {
+      rest = string.substr(prefix.size());
+      return(true);
+   }
+   return(false);
+}
