@@ -1,4 +1,4 @@
-/* $Id: unification.cc 1342 2012-02-10 18:34:09Z dreibh $
+/* $Id: unification.cc 1560 2012-11-30 18:19:41Z dreibh $
  *
  * BibTeX Converter
  * Copyright (C) 2010-2012 by Thomas Dreibholz
@@ -345,7 +345,7 @@ void unifyDate(Node* publication, Node* year, Node* month, Node* day)
    int yearNumber = 1;
    if(year != NULL) {
       yearNumber = atol(year->value.c_str());
-      if((yearNumber < 1700) || (yearNumber > 2012)) {
+      if((yearNumber < 1700) || (yearNumber > 2020)) {
          fprintf(stderr, "WARNING: Entry %s has probably invalid \"year\" section (year=%d?)!\n" ,
                  publication->keyword.c_str(), yearNumber);
       }
@@ -432,10 +432,21 @@ void unifyDate(Node* publication, Node* year, Node* month, Node* day)
 // ###### Unify "url" section ###############################################
 void unifyURL(Node* publication, Node* url)
 {
+   // ====== Remove deprecated \url{...} ====================================
    if( (url->value.substr(0, 5) == "\\url{") &&
        (url->value.substr(url->value.size() - 1) == "}") ) {
       url->value = url->value.substr(5, url->value.size() - 6);
    }
+
+   // ====== Fix IEEExplore URLs ============================================
+   if( (url->value.substr(0, 27) == "http://ieeexplore.ieee.org/") ||
+       (url->value.substr(0, 28) == "https://ieeexplore.ieee.org/") ) {
+      const size_t is = url->value.find("&isnumber=");
+      if(is == std::string::npos) {   // URL would otherwise not point to PDF download!
+         url->value += "&isnumber=";
+      }
+   }
+
    url->value = laTeXtoURL(url->value);
 }
 
